[slime-cvs] CVS slime/contrib

heller heller at common-lisp.net
Sat Sep 15 15:15:27 UTC 2007


Update of /project/slime/cvsroot/slime/contrib
In directory clnet:/tmp/cvs-serv15559/contrib

Modified Files:
	ChangeLog slime-autodoc.el slime-highlight-edits.el 
Log Message:
Let slime-setup load contribs.

* slime.el (slime-setup): Take a list of contribs to load as
argument.

* slime-autoloads.el (slime-setup): Ditto, but delay the actual
loading until slime is loaded.
(slime-setup-contribs): New function.

Add the necessary hooks when loading some contribs, so that those
contribs can be easily loaded with slime-setup.

* slime-highlight-edits.el (slime-highlight-edits-mode-on): New
function.  Add this to slime-mode-hook by default.

* slime-autodoc.el (slime-use-autodoc-mode): Change default to t.



--- /project/slime/cvsroot/slime/contrib/ChangeLog	2007/09/15 11:30:33	1.50
+++ /project/slime/cvsroot/slime/contrib/ChangeLog	2007/09/15 15:15:27	1.51
@@ -1,5 +1,15 @@
+2007-09-15  Helmut Eller  <heller at common-lisp.net>
+
+	Add the necessary hooks when loading some contribs, so that those
+	contribs can be easily loaded with slime-setup.
+
+	* slime-highlight-edits.el (slime-highlight-edits-mode-on): New
+	function.  Add this to slime-mode-hook by default.
+
+	* slime-autodoc.el (slime-use-autodoc-mode): Change default to t.
+
 2007-09-15  Ariel Badichi <abadichi at bezeqint.net>
-	
+
 	* swank-fancy-inspector.lisp (inspect-for-emacs package): When
         inspecting a package, the links in the use list and the used-by
         list lead to inspecting package names, rather than the packages
--- /project/slime/cvsroot/slime/contrib/slime-autodoc.el	2007/08/31 14:07:54	1.2
+++ /project/slime/cvsroot/slime/contrib/slime-autodoc.el	2007/09/15 15:15:27	1.3
@@ -18,10 +18,9 @@
 
 (require 'slime-parse)
 
-(defvar slime-use-autodoc-mode nil
+(defvar slime-use-autodoc-mode t
   "When non-nil always enable slime-autodoc-mode in slime-mode.")
 
-
 (defun slime-fontify-string (string)
   "Fontify STRING as `font-lock-mode' does in Lisp mode."
   (with-current-buffer (get-buffer-create " *slime-fontify*")
--- /project/slime/cvsroot/slime/contrib/slime-highlight-edits.el	2007/08/24 13:43:03	1.1
+++ /project/slime/cvsroot/slime/contrib/slime-highlight-edits.el	2007/09/15 15:15:27	1.2
@@ -1,4 +1,4 @@
 ;;; slme-higlight-edits --- highlight edited, i.e. not yet compiled, code 
 ;;
 ;; Author: William Bland <doctorbill.news at gmail.com> and others
 ;; License: GNU GPL (same license as Emacs)
@@ -88,4 +88,8 @@
     (skip-chars-forward " \n\t\r" end)
     (<= end (point))))
 
+(defun slime-highlight-edits-mode-on () (slime-highlight-edits-mode 1))
+
+(add-hook 'slime-mode-hook 'slime-highlight-edits-mode-on)
+
 (provide 'slime-highlight-edits)
\ No newline at end of file
@@ -1,4 +1,4 @@
-;;; slme-higlight-edits --- highlight edited, i.e. not yet compiled, code 
+;;; slime-higlight-edits --- highlight edited, i.e. not yet compiled, code 
 ;;
 ;; Author: William Bland <doctorbill.news at gmail.com> and others




More information about the slime-cvs mailing list